Yet Another Python Repo Tool
############################
:date: 2013-09-05 09:51
:tags: python, github, pip, pypi
:category: \*nix


General Overview
----------------

This is a tool that will build a directory of links a simple pypi index and will do it all as python wheels.


More documentation coming soon...
